SurfaceConfig class

Constructors

SurfaceConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

theme SurfaceThemeData
getter/setter pair
themeModeType ThemeMode
getter/setter pair

Static Methods

config({required SurfaceThemeData themeLight, required SurfaceThemeData themeDark, required ThemeMode themeModeType}) → void